@@ -632,7 +632,7 @@ class LaharFlowData(object):
         last_outfile = self.get_snapshot_files()[-1]
         
         if data is None:
-            data = self.rasters[last_outfile]
+            data = self.raster(last_outfile)
         if 'elevation_change' not in list(data.keys()):
             data = self.raster(last_outfile)
             
@@ -655,7 +655,7 @@ class LaharFlowData(object):
     def max_depth(self, data=None, vmin=None):
 
         if data is None:
-            data = self.rasters['MaxHeights']
+            data = self.raster['MaxHeights']
         if 'maximum_depth' not in list(data.keys()):
             data = self.raster('MaxHeights.txt')
         
